==> senior_design_system-0.10.13.tar.gz: example/lib/views/bottom_sheet.example.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_system/senior_design_system.dart';

class BottomSheetExample extends StatelessWidget {
  const BottomSheetExample({
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    var screenHeight = MediaQuery.of(context).size.height;
    var appBarHeiht = Size.fromHeight(100.0);
    var bottomSheetHeight = screenHeight - appBarHeiht.height;

    return Scaffold(
      body: Center(
        child: SeniorButton(
          label: 'Mostrar',
          onPressed: () {
            SeniorBottomSheet.showBottomSheet(
              enableDrag: true,
              isDismissible: true,
              height: bottomSheetHeight,
              context: context,
              hasCloseButton: true,
              title: 'Busque um colega que você deseja enviar um feedback',
              onTapCloseButton: () {
                Navigator.pop(context);
              },
              content: <Widget>[
                Expanded(
                  child: ListView.separated(
                    padding: EdgeInsets.all(16.0),
                    separatorBuilder: (_, __) => SizedBox(
                      height: 12.0,
                    ),
                    itemCount: 20,
                    itemBuilder: (_, index) {
                      return Text(
                        index.toString(),
                      );
                    },
                  ),
                ),
              ],
            );
          },
        ),
      ),
    );
  }
}

==> senior_design_system-0.17.0.tar.gz: example/lib/views/bottom_sheet.example.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_system/components/senior_bottom_sheet/senior_bottom_sheet.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class BottomSheetExample extends StatelessWidget {
  const BottomSheetExample({
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final double screenHeight = MediaQuery.of(context).size.height;
    final Size appBarHeiht = Size.fromHeight(100.0);
    final double bottomSheetHeight = screenHeight - appBarHeiht.height;

    return Scaffold(
      body: Center(
        child: SeniorButton(
          label: 'Mostrar',
          onPressed: () {
            SeniorBottomSheet.showBottomSheet(
              enableDrag: true,
              isDismissible: true,
              height: bottomSheetHeight,
              context: context,
              hasCloseButton: true,
              title: 'Busque um colega que você deseja enviar um feedback',
              onTapCloseButton: () {
                Navigator.pop(context);
              },
              content: <Widget>[
                Expanded(
                  child: ListView.separated(
                    padding: EdgeInsets.all(SeniorSpacing.normal),
                    separatorBuilder: (_, __) => SizedBox(
                      height: SeniorSpacing.small,
                    ),
                    itemCount: 20,
                    itemBuilder: (_, index) {
                      return Text(
                        index.toString(),
                      );
                    },
                  ),
                ),
              ],
            );
          },
        ),
      ),
    );
  }
}
